@@ -2,14 +2,13 @@ import os
 import sys
 from typing import List
 from tqatest.app.core.errors import PredictException, ModelLoadException
-from tqatest.ml.model import TrainedModel_c++
 # from anscenter.app.core.config import MODEL_NAME, MODEL_PATH, MODEL_ID
 from loguru import logger
-# import ml.libs.annhub as annhub
 from tqatest.ml.libs import annhub
+from importlib.resources import read_text
 
 MODEL_NAME = "TrainedModel_c++.ann"
-MODEL_PATH = ""
+MODEL_PATH = "ml/model/"
 MODEL_ID = 5122020
 
 class MachineLearningModel(object):
@@ -18,18 +17,18 @@ class MachineLearningModel(object):
         self.load()
 
     def load(self):
-        if MODEL_PATH.endswith("/"):
-            path = f"{MODEL_PATH}{MODEL_NAME}"
-        else:
-            path = f"{MODEL_PATH}/{MODEL_NAME}"
+        # if MODEL_PATH.endswith("/"):
+        #     path = f"{MODEL_PATH}{MODEL_NAME}"
+        # else:
+        #     path = f"{MODEL_PATH}/{MODEL_NAME}"
 
-        path = os.path.abspath(os.path.join(os.getcwd(), path))
-
-        if not os.path.exists(path):
-            message = f"Machine learning model at {path} not exists!"
-            logger.error(message)
-            raise FileNotFoundError(message)
+        # path = os.path.abspath(os.path.join(os.getcwd(), path))
 
+        # if not os.path.exists(path):
+        #     message = f"Machine learning model at {path} not exists!"
+        #     logger.error(message)
+        #     raise FileNotFoundError(message)
+        path = read_text("ml/model/", "TrainedModel_c++.ann")
         self.load_model(path)
     
     def load_model(self, path : str):
